@@ -1,4 +1,4 @@
-# $Id: Writable.pm 1476 2010-11-15 14:06:02Z rvos $
+# $Id: Writable.pm 1586 2010-12-16 00:59:38Z rvos $
 package Bio::Phylo::NeXML::Writable;
 use strict;
 use Bio::Phylo ();
@@ -224,6 +224,31 @@ xml element structure called <node/>
 		}
 	}
 
+=item set_name()
+
+Sets invocant name.
+
+ Type    : Mutator
+ Title   : set_name
+ Usage   : $obj->set_name($name);
+ Function: Assigns an object's name.
+ Returns : Modified object.
+ Args    : Argument must be a string. Ensure that this string is safe to use for
+           whatever output format you want to use (this differs between xml and
+           nexus, for example).
+
+=cut
+
+	sub set_name {
+		my ( $self, $name ) = @_;
+		if ( defined $name ) {
+			return $self->set_attributes( 'label' => $name );
+		}
+		else {
+			return $self;
+		}
+	}
+
 =item set_attributes()
 
 Assigns attributes for the element.
@@ -389,6 +414,34 @@ Retrieves tag name for the element.
 		}
 	}
 
+=item get_name()
+
+Gets invocant's name.
+
+ Type    : Accessor
+ Title   : get_name
+ Usage   : my $name = $obj->get_name;
+ Function: Returns the object's name.
+ Returns : A string
+ Args    : None
+
+=cut
+	
+	sub get_name {
+		my $self = shift;
+		my $id = $self->get_id;
+		if ( ! $attributes{$id} ) {			
+			$attributes{$id} = {};
+		}
+		if ( defined $attributes{$id}->{'label'} ) {
+			return $attributes{$id}->{'label'};		
+		}
+		else {
+			return '';
+		}
+		
+	}
+
 =item get_xml_tag()
 
 Retrieves tag string
@@ -765,6 +818,29 @@ Serializes invocant to XML.
 		}
 	}
 
+=item to_json()
+
+Serializes object to JSON string
+
+ Type    : Serializer
+ Title   : to_json()
+ Usage   : print $obj->to_json();
+ Function: Serializes object to JSON string
+ Returns : String 
+ Args    : None
+ Comments:
+
+=cut
+
+    sub to_json { 
+	my $self = shift;
+    	eval { require XML::XML2JSON };
+    	if ( $@ ) {
+    		throw 'ExtensionError' => "Can't load XML::XML2JSON - $@";    		
+    	}
+	return XML::XML2JSON->new->convert($self->to_xml);
+    }
+
 	sub _cleanup { 
 		my $self = shift;
 		my $id = $self->get_id;
@@ -785,7 +861,7 @@ Also see the manual: L<Bio::Phylo::Manual> and L<http://rutgervos.blogspot.com>.
 
 =head1 REVISION
 
- $Id: Writable.pm 1476 2010-11-15 14:06:02Z rvos $
+ $Id: Writable.pm 1586 2010-12-16 00:59:38Z rvos $
 
 =cut
 
